Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon API Gateway Management V2.

Actions, resources, and condition keys for Amazon API Gateway Management V2 - Service Authorization Reference

# Actions, resources, and condition keys for Amazon API Gateway Management V2

Amazon API Gateway Management V2 (service prefix: `apigateway` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by Amazon API Gateway Management V2
- Resource types defined by Amazon API Gateway Management V2
- Condition keys for Amazon API Gateway Management V2

## Actions defined by Amazon API Gateway Management V2

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
DELETE | Grants permission to delete a particular resource | Write | AccessLogSettings |  |
Api |  |
ApiMapping |  |
Authorizer |  |
AuthorizersCache |  |
Cors |  |
Deployment |  |
Integration |  |
IntegrationResponse |  |
Model |  |
Route |  |
RouteRequestParameter |  |
RouteResponse |  |
RouteSettings |  |
Stage |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
GET | Grants permission to read a particular resource | Read | AccessLogSettings |  |
Api |  |
ApiMapping |  |
ApiMappings |  |
Apis |  |
Authorizer |  |
Authorizers |  |
AuthorizersCache |  |
Cors |  |
Deployment |  |
Deployments |  |
ExportedAPI |  |
Integration |  |
IntegrationResponse |  |
IntegrationResponses |  |
Integrations |  |
Model |  |
ModelTemplate |  |
Models |  |
Route |  |
RouteRequestParameter |  |
RouteResponse |  |
RouteResponses |  |
RouteSettings |  |
Routes |  |
Stage |  |
Stages |  |
PATCH | Grants permission to update a particular resource | Write | Api |  |
ApiMapping |  |
Authorizer |  |
Deployment |  |
Integration |  |
IntegrationResponse |  |
Model |  |
Route |  |
RouteRequestParameter |  |
RouteResponse |  |
Stage |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
POST | Grants permission to create a particular resource | Write | ApiMappings |  |
Apis |  |
Authorizers |  |
Deployments |  |
IntegrationResponses |  |
Integrations |  |
Models |  |
RouteResponses |  |
Routes |  |
Stages |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
PUT | Grants permission to update a particular resource | Write | Apis |  |
| aws:RequestTag/${TagKey} aws:TagKeys |

## Resource types defined by Amazon API Gateway Management V2

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
AccessLogSettings | `arn:$ { Partition}:apigateway:$ { Region}::/apis/$ { ApiId}/stages/$ { StageName}/accesslogsettings` |
Api | `arn:$ { Partition}:apigateway:$ { Region}::/apis/$ { ApiId}` | apigateway:Request/ApiKeyRequired apigateway:Request/ApiName apigateway:Request/AuthorizerType apigateway:Request/AuthorizerUri apigateway:Request/DisableExecuteApiEndpoint apigateway:Request/EndpointType apigateway:Request/RouteAuthorizationType apigateway:Resource/ApiKeyRequired apigateway:Resource/ApiName apigateway:Resource/AuthorizerType apigateway:Resource/AuthorizerUri apigateway:Resource/DisableExecuteApiEndpoint apigateway:Resource/EndpointType apigateway:Resource/RouteAuthorizationType aws:ResourceTag/${TagKey}
Apis | `arn:$ { Partition}:apigateway:$ { Region}::/apis` | apigateway:Request/ApiKeyRequired apigateway:Request/ApiName apigateway:Request/AuthorizerType apigateway:Request/AuthorizerUri apigateway:Request/DisableExecuteApiEndpoint apigateway:Request/EndpointType apigateway:Request/RouteAuthorizationType aws:ResourceTag/${TagKey}
ApiMapping | `arn:$ { Partition}:apigateway:$ { Region}::/domainnames/$ { DomainName}/apimappings/$ { ApiMappingId}` | aws:ResourceTag/${TagKey}
ApiMappings | `arn:$ { Partition}:apigateway:$ { Region}::/domainnames/$ { DomainName}/apimappings` | aws:ResourceTag/${TagKey}
Authorizer | `arn:$ { Partition}:apigateway:$ { Region}::/apis/$ { ApiId}/authorizers/$ { AuthorizerId}` | apigateway:Request/AuthorizerType apigateway:Request/AuthorizerUri apigateway:Resource/AuthorizerType apigateway:Resource/AuthorizerUri aws:ResourceTag/${TagKey}
Authorizers | `arn:$ { Partition}:apigateway:$ { Region}::/apis/$ { ApiId}/authorizers` | apigateway:Request/AuthorizerType apigateway:Request/AuthorizerUri aws:ResourceTag/${TagKey}
AuthorizersCache | `arn:$ { Partition}:apigateway:$ { Region}::/apis/$ { ApiId}/stages/$ { StageName}/cache/authorizers` |
Cors | `arn:$ { Partition}:apigateway:$ { Region}::/apis/$ { ApiId}/cors` |
Deployment | `arn:$ { Partition}:apigateway:$ { Region}::/apis/$ { ApiId}/deployments/$ { DeploymentId}` | aws:ResourceTag/${TagKey}
Deployments | `arn:$ { Partition}:apigateway:$ { Region}::/apis/$ { ApiId}/deployments` | apigateway:Request/StageName aws:ResourceTag/${TagKey}
ExportedAPI | `arn:$ { Partition}:apigateway:$ { Region}::/apis/$ { ApiId}/exports/$ { Specification}` |
Integration | `arn:$ { Partition}:apigateway:$ { Region}::/apis/$ { ApiId}/integrations/$ { IntegrationId}` | aws:ResourceTag/${TagKey}
Integrations | `arn:$ { Partition}:apigateway:$ { Region}::/apis/$ { ApiId}/integrations` | aws:ResourceTag/${TagKey}
IntegrationResponse | `arn:$ { Partition}:apigateway:$ { Region}::/apis/$ { ApiId}/integrations/$ { IntegrationId}/integrationresponses/$ { IntegrationResponseId}` |
IntegrationResponses | `arn:$ { Partition}:apigateway:$ { Region}::/apis/$ { ApiId}/integrations/$ { IntegrationId}/integrationresponses` |
Model | `arn:$ { Partition}:apigateway:$ { Region}::/apis/$ { ApiId}/models/$ { ModelId}` | aws:ResourceTag/${TagKey}
Models | `arn:$ { Partition}:apigateway:$ { Region}::/apis/$ { ApiId}/models` | aws:ResourceTag/${TagKey}
ModelTemplate | `arn:$ { Partition}:apigateway:$ { Region}::/apis/$ { ApiId}/models/$ { ModelId}/template` |
Route | `arn:$ { Partition}:apigateway:$ { Region}::/apis/$ { ApiId}/routes/$ { RouteId}` | apigateway:Request/ApiKeyRequired apigateway:Request/RouteAuthorizationType apigateway:Resource/ApiKeyRequired apigateway:Resource/RouteAuthorizationType aws:ResourceTag/${TagKey}
Routes | `arn:$ { Partition}:apigateway:$ { Region}::/apis/$ { ApiId}/routes` | apigateway:Request/ApiKeyRequired apigateway:Request/RouteAuthorizationType aws:ResourceTag/${TagKey}
RouteResponse | `arn:$ { Partition}:apigateway:$ { Region}::/apis/$ { ApiId}/routes/$ { RouteId}/routeresponses/$ { RouteResponseId}` |
RouteResponses | `arn:$ { Partition}:apigateway:$ { Region}::/apis/$ { ApiId}/routes/$ { RouteId}/routeresponses` |
RouteRequestParameter | `arn:$ { Partition}:apigateway:$ { Region}::/apis/$ { ApiId}/routes/$ { RouteId}/requestparameters/$ { RequestParameterKey}` |
RouteSettings | `arn:$ { Partition}:apigateway:$ { Region}::/apis/$ { ApiId}/stages/$ { StageName}/routesettings/$ { RouteKey}` |
Stage | `arn:$ { Partition}:apigateway:$ { Region}::/apis/$ { ApiId}/stages/$ { StageName}` | apigateway:Request/AccessLoggingDestination apigateway:Request/AccessLoggingFormat apigateway:Resource/AccessLoggingDestination apigateway:Resource/AccessLoggingFormat aws:ResourceTag/${TagKey}
Stages | `arn:$ { Partition}:apigateway:$ { Region}::/apis/$ { ApiId}/stages` | apigateway:Request/AccessLoggingDestination apigateway:Request/AccessLoggingFormat aws:ResourceTag/${TagKey}

## Condition keys for Amazon API Gateway Management V2

Amazon API Gateway Management V2 defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
apigateway:Request/AccessLoggingDestination | Filters access by access log destination. Available during the CreateStage and UpdateStage operations | String
apigateway:Request/AccessLoggingFormat | Filters access by access log format. Available during the CreateStage and UpdateStage operations | String
apigateway:Request/ApiKeyRequired | Filters access based on whether an API key is required or not. Available during the CreateRoute and UpdateRoute operations. Also available as a collection during import and reimport | ArrayOfBool
apigateway:Request/ApiName | Filters access by API name. Available during the CreateApi and UpdateApi operations | String
apigateway:Request/AuthorizerType | Filters access by type of authorizer in the request, for example REQUEST or JWT. Available during CreateAuthorizer and UpdateAuthorizer. Also available during import and reimport as an ArrayOfString | ArrayOfString
apigateway:Request/AuthorizerUri | Filters access by URI of a Lambda authorizer function. Available during CreateAuthorizer and UpdateAuthorizer. Also available during import and reimport as an ArrayOfString | ArrayOfString
apigateway:Request/DisableExecuteApiEndpoint | Filters access by status of the default execute-api endpoint. Available during the CreateApi and UpdateApi operations | Bool
apigateway:Request/EndpointType | Filters access by endpoint type. Available during the CreateDomainName, UpdateDomainName, CreateApi, and UpdateApi operations | String
apigateway:Request/MtlsTrustStoreUri | Filters access by URI of the truststore used for mutual TLS authentication. Available during the CreateDomainName and UpdateDomainName operations | String
apigateway:Request/MtlsTrustStoreVersion | Filters access by version of the truststore used for mutual TLS authentication. Available during the CreateDomainName and UpdateDomainName operations | String
apigateway:Request/RouteAuthorizationType | Filters access by authorization type, for example NONE, AWS_IAM, CUSTOM, JWT. Available during the CreateRoute and UpdateRoute operations. Also available as a collection during import | ArrayOfString
apigateway:Request/SecurityPolicy | Filters access by TLS version. Available during the CreateDomain and UpdateDomain operations | ArrayOfString
apigateway:Request/StageName | Filters access by stage name of the deployment that you attempt to create. Available during the CreateDeployment operation | String
apigateway:Resource/AccessLoggingDestination | Filters access by access log destination of the current Stage resource. Available during the UpdateStage and DeleteStage operations | String
apigateway:Resource/AccessLoggingFormat | Filters access by access log format of the current Stage resource. Available during the UpdateStage and DeleteStage operations | String
apigateway:Resource/ApiKeyRequired | Filters access based on whether an API key is required or not for the existing Route resource. Available during the UpdateRoute and DeleteRoute operations. Also available as a collection during reimport | ArrayOfBool
apigateway:Resource/ApiName | Filters access by API name. Available during the UpdateApi and DeleteApi operations | String
apigateway:Resource/AuthorizerType | Filters access by the current type of authorizer, for example REQUEST or JWT. Available during UpdateAuthorizer and DeleteAuthorizer operations. Also available during import and reimport as an ArrayOfString | ArrayOfString
apigateway:Resource/AuthorizerUri | Filters access by the URI of the current Lambda authorizer associated with the current API. Available during UpdateAuthorizer and DeleteAuthorizer. Also available as a collection during reimport | ArrayOfString
apigateway:Resource/DisableExecuteApiEndpoint | Filters access by status of the default execute-api endpoint. Available during the UpdateApi and DeleteApi operations | Bool
apigateway:Resource/EndpointType | Filters access by endpoint type. Available during the UpdateDomainName, DeleteDomainName, UpdateApi, and DeleteApi operations | String
apigateway:Resource/MtlsTrustStoreUri | Filters access by URI of the truststore used for mutual TLS authentication. Available during the UpdateDomainName and DeleteDomainName operations | String
apigateway:Resource/MtlsTrustStoreVersion | Filters access by version of the truststore used for mutual TLS authentication. Available during the UpdateDomainName and DeleteDomainName operations | String
apigateway:Resource/RouteAuthorizationType | ilters access by authorization type of the existing Route resource, for example NONE, AWS_IAM, CUSTOM. Available during the UpdateRoute and DeleteRoute operations. Also available as a collection during reimport | ArrayOfString
apigateway:Resource/SecurityPolicy | Filters access by TLS version. Available during the UpdateDomainName and DeleteDomainName operations | ArrayOfString
aws:RequestTag/${TagKey} | Filters actions based on the presence of tag key-value pairs in the request | String
aws:ResourceTag/${TagKey} | Filters actions based on tag key-value pairs attached to the resource | String
aws:TagKeys | Filters actions based on the presence of tag keys in the request | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.